/*======================================================*
Purpose 	:	长护险对健康的影响
Data 1		: 	城市-年份层面60岁以上老年人不健康比例
Data 2		: 	长护险制度特征数据
Data 3		: 	城市统计年鉴数据
Created by	:	张毅 zhangyieco@gmail.com
Last Modify : 	20241026
*=======================================================*/
	

	clear all
	set	more off
	set scrollbufsize 2048000
	capture log close 


	global replication "/Users/zhangyi/Desktop/replication"	
	global rawdata  "$replication/rawdata"
	global workingdata  "$replication/workingdata"
	global table  "$replication/output/table"
	global figure  "$replication/output/figure"
	cd "$replication" 


	use "$rawdata/census_ltc.dta",clear 
	xtset city_code year 
*变量说明
* unhealth_ratio 城市60岁以上老人自评不健康比例
* did 		：Treat * Post 
* var1 		：年末总人口（万人）
* var64 	：地区生产总值（亿元）
* var181 	：医院、卫生院数量（个）
* var183 	：医院、卫生院床位数（张）
* var185 	：执业或助理医师数（人）
* city_code ：城市代码
* year 		：年份


*=========== 正文表8 ==============*	
*=========== 正文表8 ==============*	
*=========== 正文表8 ==============*
	reghdfe unhealth_ratio did ,absorb(city_code year) vce(cluster city_code)
	outreg2 using "$table/table8.doc",keep(did)  adjr2  bdec(3) addtext(City FE,Yes,Year FE,Yes,City Control,No)  replace    

	reghdfe unhealth_ratio did var1 var64  var181 var183 var185 ,absorb(city_code year) vce(cluster city_code)
	outreg2 using "$table/table8.doc",keep(did)  adjr2  bdec(3) addtext(City FE,Yes,Year FE,Yes,City Control,Yes)  append     



*=========== 附录-图B1==============*	
*=========== 附录-图B1==============*	
*=========== 附录-图B1==============*

preserve
	replace ltc_2=0
	reghdfe unhealth_ratio ltc_1 ltc_2 ltc_3 var1 var64 var181 var183 var185 ,absorb(city_code year) vce(cluster city_code)
	estimates store unhealth_ratio
restore

	coefplot (unhealth_ratio,omitted keep(ltc_1 ltc_2 ltc_3) label(不健康比例) msymbol(S) mcolor(gs5) recast(rcap) color(pink) lp(thin) ciopts(recast(rcap) color(gs5)) ),  ///
			vertical drop(_cons)  yline(0,lp(dash)) xline(1.95(.001)2.05, lcolor(gs14)) ///
		ylabel(-0.15(0.05)0.1, nogrid)  ytitle("事"	"件""分""析""法""估""计""结""果",size(9pt) angle(90) orientation(horizontal)) ///
		title("长护险对老年人健康的影响",size(10pt) color(black)) ///
		xtitle("年份", size(9pt)) ///
		legend ( ring(0) pos(11) size(small) row(3)) ///
		graphregion(color(white)) //白底
		graph save "$figure/Appendix_B1.gph",replace 





		
